@@ -19,9 +19,12 @@ import uuid
 import aiohttp
 
 import octobot_commons.enums as enums
+import octobot_commons.constants as commons_constants
 import octobot_commons.logging as logging
 import octobot_commons.configuration as configuration
 import octobot_commons.signals as signals
+import octobot_commons.databases as databases
+import octobot_commons.tree as commons_tree
 
 import octobot_services.api as service_api
 import octobot_trading.api as trading_api
@@ -35,6 +38,7 @@ import octobot.octobot_channel_consumer as octobot_channel_consumer
 import octobot.octobot_api as octobot_api
 import octobot.initializer as initializer
 import octobot.producers as producers
+import octobot.storage as storage
 
 """Main OctoBot class:
 - Create all indicators and thread for each cryptocurrencies in config """
@@ -90,6 +94,7 @@ class OctoBot:
         # Initialize octobot main tools
         self.initializer = initializer.Initializer(self)
         self.task_manager = task_manager.TaskManager(self)
+        self._init_metadata_run_task = None
 
         # Producers
         self.exchange_producer = None
@@ -103,11 +108,13 @@ class OctoBot:
     async def initialize(self):
         self.stopped = asyncio.Event()
         self.community_auth.init_account()
-        await self.initializer.create()
+        self._log_config()
+        await self.initializer.create(True)
         await self._start_tools_tasks()
         await logger.init_octobot_chan_logger(self.bot_id)
         await self.create_producers()
         await self.start_producers()
+        await self._post_initialize()
 
     async def create_producers(self):
         self.exchange_producer = producers.ExchangeProducer(self.global_consumer.octobot_channel, self,
@@ -122,7 +129,6 @@ class OctoBot:
         # Start service feeds now that evaluators registered their feed requirements
         await self.service_feed_producer.run()
         await self.interface_producer.run()
-        await self._post_initialize()
 
     async def _post_initialize(self):
         self.initialized = True
@@ -132,18 +138,49 @@ class OctoBot:
         await service_api.send_notification(
             service_api.create_notification(f"{constants.PROJECT_NAME} {constants.LONG_VERSION} is starting ...",
                                             markdown_format=enums.MarkdownFormat.ITALIC))
+        self._init_metadata_run_task = asyncio.create_task(self._store_run_metadata_when_available())
+
+    async def _wait_for_run_data_init(self, exchange_managers, timeout):
+        for exchange_manager in exchange_managers:
+            for topic in constants.REQUIRED_TOPIC_FOR_DATA_INIT:
+                await commons_tree.EventProvider.instance().wait_for_event(
+                    self.bot_id,
+                    commons_tree.get_exchange_path(
+                        trading_api.get_exchange_name(exchange_manager),
+                        topic.value
+                    ),
+                    timeout
+                )
+
+    async def _store_run_metadata_when_available(self):
+        run_metadata_init_timeout = 5 * commons_constants.MINUTE_TO_SECONDS
+        # first wait for all exchanges to be created
+        await asyncio.wait_for(self.exchange_producer.created_all_exchanges.wait(), run_metadata_init_timeout)
+        exchange_managers = [
+            trading_api.get_exchange_manager_from_exchange_id(exchange_manager_id)
+            for exchange_manager_id in self.exchange_producer.exchange_manager_ids
+        ]
+        await self._wait_for_run_data_init(exchange_managers, run_metadata_init_timeout)
+        await storage.clear_run_metadata(self.bot_id)
+        await storage.store_run_metadata(self.bot_id, exchange_managers, self.start_time)
 
     async def stop(self):
         try:
+            self.logger.debug("Stopping ...")
+            if self._init_metadata_run_task is not None and not self._init_metadata_run_task.done():
+                self._init_metadata_run_task.cancel()
             signals.SignalPublisher.instance().stop()
+            await self.evaluator_producer.stop()
             await self.exchange_producer.stop()
             await self.community_auth.stop()
             await self.service_feed_producer.stop()
             service_api.stop_services()
             await self.interface_producer.stop()
+            await databases.close_bot_storage(self.bot_id)
+
         finally:
             self.stopped.set()
-            self.logger.info("Shutting down.")
+            self.logger.info("Stopped, now shutting down.")
 
     async def _start_tools_tasks(self):
         self._init_community()
@@ -152,6 +189,19 @@ class OctoBot:
     def _init_community(self):
         self.community_handler = community.CommunityManager(self.octobot_api)
 
+    def _log_config(self):
+        exchanges = [
+            f"{exchange}[{config.get(commons_constants.CONFIG_EXCHANGE_TYPE, commons_constants.CONFIG_EXCHANGE_TYPE)}]"
+            for exchange, config in self.config[commons_constants.CONFIG_EXCHANGES].items()
+            if config.get(commons_constants.CONFIG_ENABLED_OPTION, True)
+        ]
+        has_real_trader = trading_api.is_trader_enabled_in_config(self.config)
+        has_simulated_trader = trading_api.is_trader_simulator_enabled_in_config(self.config)
+        trader_str = "real trader" if has_real_trader else "simulated trader" if has_simulated_trader else "no trader"
+        traded_symbols = trading_api.get_config_symbols(self.config, True)
+        self.logger.info(f"Starting OctoBot with {trader_str} on {', '.join(exchanges)} "
+                         f"trading {', '.join(set(traded_symbols))} and using bot_id: {self.bot_id}")
+
     def get_edited_config(self, config_key, dict_only=True):
         return self.configuration_manager.get_edited_config(config_key, dict_only)
 
@@ -170,8 +220,9 @@ class OctoBot:
         except StopIteration:
             return None
 
-    def run_in_main_asyncio_loop(self, coroutine, log_exceptions=True):
-        return self.task_manager.run_in_main_asyncio_loop(coroutine, log_exceptions=log_exceptions)
+    def run_in_main_asyncio_loop(self, coroutine, log_exceptions=True,
+                                 timeout=commons_constants.DEFAULT_FUTURE_TIMEOUT):
+        return self.task_manager.run_in_main_asyncio_loop(coroutine, log_exceptions=log_exceptions, timeout=timeout)
 
     def set_watcher(self, watcher):
         self.task_manager.watcher = watcher
